@@ -30,6 +30,8 @@
 #include <unistd.h>
 
 #include "argp.h"
+#include "gl_array_list.h"
+#include "gl_xlist.h"
 #include "progname.h"
 
 #include "gettext.h"
@@ -39,9 +41,11 @@
 #include "manconfig.h"
 
 #include "cleanup.h"
+#include "encodings.h"
 #include "error.h"
 #include "pipeline.h"
 #include "decompress.h"
+#include "glcontainers.h"
 #include "sandbox.h"
 
 #include "manconv.h"
@@ -51,43 +55,38 @@ man_sandbox *sandbox;
 
 static const char *from_codes;
 static char *to_code;
-static char **from_code;
+static gl_list_t from_code;
 static const char *filename;
 
-static char **split_codes (const char *codestr)
+static gl_list_t split_codes (const char *codestr)
 {
-	char *codestrtok = xstrdup (codestr);
-	char *codestrtok_ptr = codestrtok;
+	char *codestrtok, *codestrtok_ptr;
 	char *tok;
-	size_t codearray_cur = 0, codearray_alloc = 0;
-	char **codearray = NULL;
+	gl_list_t codelist = new_string_list (GL_ARRAY_LIST, true);
+
+	if (!codestr)
+		return codelist;
+
+	codestrtok = xstrdup (codestr);
+	codestrtok_ptr = codestrtok;
 
 	for (tok = strsep (&codestrtok_ptr, ":"); tok;
 	     tok = strsep (&codestrtok_ptr, ":")) {
 		if (!*tok)
 			continue;	/* ignore empty fields */
-		if (codearray_cur >= codearray_alloc)
-			codearray = x2nrealloc
-				(codearray,
-				 &codearray_alloc, sizeof *codearray);
-		codearray[codearray_cur++] = xstrdup (tok);
+		gl_list_add_last (codelist, xstrdup (tok));
 	}
 
-	if (codearray_cur >= codearray_alloc)
-		codearray = x2nrealloc (codearray,
-					&codearray_alloc, sizeof *codearray);
-	codearray[codearray_cur] = NULL;
-
 	free (codestrtok);
 
-	return codearray;
+	return codelist;
 }
 
 const char *argp_program_version = "manconv " PACKAGE_VERSION;
 const char *argp_program_bug_address = PACKAGE_BUGREPORT;
 error_t argp_err_exit_status = FAIL;
 
-static const char args_doc[] = N_("-f CODE[:...] -t CODE [FILENAME]");
+static const char args_doc[] = N_("[-f CODE[:...]] -t CODE [FILENAME]");
 
 static struct argp_option options[] = {
 	{ "from-code",	'f',	N_("CODE[:...]"),
@@ -127,19 +126,11 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 			filename = arg;
 			return 0;
 		case ARGP_KEY_SUCCESS:
-			if (!from_codes)
-				argp_error (state,
-					    _("must specify an input "
-					      "encoding"));
 			if (!to_code)
 				argp_error (state,
 					    _("must specify an output "
 					      "encoding"));
 			from_code = split_codes (from_codes);
-			if (!from_code || !*from_code)
-				argp_error (state,
-					    _("must specify an input "
-					      "encoding"));
 			return 0;
 	}
 	return ARGP_ERR_UNKNOWN;
@@ -150,7 +141,6 @@ static struct argp argp = { options, parse_opt, args_doc };
 int main (int argc, char *argv[])
 {
 	pipeline *p;
-	char **try_from_code;
 
 	set_program_name (argv[0]);
 
@@ -170,12 +160,36 @@ int main (int argc, char *argv[])
 		p = decompress_fdopen (dup (STDIN_FILENO));
 	pipeline_start (p);
 
+	if (!gl_list_size (from_code)) {
+		char *lang, *page_encoding;
+
+		/* Note that we don't need to explicitly check the page's
+		 * preprocessor encoding here, as the manconv function will
+		 * do that itself and override the requested input encoding
+		 * with it if it finds one.
+		 */
+		lang = lang_dir (filename);
+		page_encoding = get_page_encoding (lang);
+		if (STREQ (page_encoding, "UTF-8")) {
+			/* Steal memory. */
+			gl_list_add_last (from_code, page_encoding);
+			debug ("guessed input encoding %s for %s\n",
+			       page_encoding, filename);
+		} else {
+			gl_list_add_last (from_code, xstrdup ("UTF-8"));
+			/* Steal memory. */
+			gl_list_add_last (from_code, page_encoding);
+			debug ("guessed input encodings UTF-8:%s for %s\n",
+			       page_encoding, filename);
+		}
+
+		free (lang);
+	}
+
 	manconv (p, from_code, to_code);
 
-	for (try_from_code = from_code; *try_from_code; ++try_from_code)
-		free (*try_from_code);
 	free (to_code);
-	free (from_code);
+	gl_list_free (from_code);
 
 	pipeline_wait (p);
 
